require "snake"
require "tile"

Game = Object:extend()

map = {}
objects = {}
snake = {}
direction = 2
local canMove = true

function Game:new(level)
	self.level = level
	snake = {}
	self.loadMap(self)
	self.visible = 0
end

function Game:loadMap()
	-- loading level from file
	for line in love.filesystem.lines("level" .. tostring(self.level) .. ".lst")	do 
		table.insert(map, line)
	end
	
	-- instantiate objects on map
	for index, str in ipairs(map) do
		for i = 1, #str do
			local letter = str:sub(i, i)
			if letter == "X" then
				table.insert(objects, Tile(i, index, "wall"))
			elseif letter == "S" then
				table.insert(objects, Tile(i, index, "floor"))
				snake[1] = Snake(i, index, 10)
			elseif letter == "_" then 
				table.insert(objects, Tile(i, index, "floor"))
			end
		end
	end
end

function Game:update(dt)
	self.visible = math.min(255, self.visible + 100 * dt)
	if canMove == false and math.floor(snake[1].realX) % 32 == 0 and math.floor(snake[1].realY) % 32 == 0 then
		dir = direction
		canMove = true
	end
	snake[1]:update(dt)
	snake[1].newX = math.floor(math.floor(snake[1].realX)/32)
	snake[1].newY = math.floor(math.floor(snake[1].realY)/32)
	if snake[1].newX ~= snake[1].x or snake[1].newY ~= snake[1].y then
		table.insert(snake, 2, Snake(snake[1].x, snake[1].y))
		snake[1].x = snake[1].newX
		snake[1].y = snake[1].newY
	end
end

function love.keypressed(key)
	-- adding change direction to the queqe
	if key == "left" and canMove == true then
		if direction == 1 then 
			direction = 4
		else
			direction = direction - 1
		end
		canMove = false
	elseif key == "right" and canMove == true then
		if direction == 4 then
			direction = 1
		else
			direction = direction + 1
		end
		canMove = false
	end
end

function Game:draw()
	love.graphics.setColor(255,255,255,255)
	for i, v in ipairs(objects) do
		v:draw()
	end
	colorChange = 255/#snake * 0.5
	for i = #snake, 1, -1 do
		love.graphics.setColor(colorChange * (i - 1), colorChange * (i - 1), 255, 255)
		snake[i]:draw()
	end
	love.graphics.setColor(255,0,255,self.visible)
	love.graphics.setFont(normalFont)
	love.graphics.printf("Level: " .. self.level, 0, 50, WINDOW_WIDTH, "center")
	love.graphics.setColor(255,255,255,255)
	--print("Snake newx: " .. snake[1].newX)
	--print("Snake newy: " .. snake[1].newY)
	--print("Snake x: " .. snake[1].x)
	--print("Snake y: " .. snake[1].y)
end