Object = require "classic"
require "game"

WINDOW_WIDTH = 960
WINDOW_HEIGHT = 640

function love.load()
	-- window
	love.window.setMode(WINDOW_WIDTH, WINDOW_HEIGHT, {vsync = true, resizable = false, fullscreen = false})
	love.window.setTitle("Snake Expansion")
	love.graphics.setDefaultFilter('nearest', 'nearest')
	
	-- sounds 
	winSound = love.audio.newSource("win.wav", "static")
	menuSound = love.audio.newSource("menu.wav", "static")
	moveSound = love.audio.newSource("move.wav", "static")
	itemSound = love.audio.newSource("item.wav", "static")
	collisionSound = love.audio.newSource("collision.wav", "static")
	
	-- graphics
	background = love.graphics.newImage("background.png")
	ring = love.graphics.newImage("ring.png")
	smallFont = love.graphics.newFont("Liquid.ttf", 30)
	normalFont = love.graphics.newFont("Liquid.ttf", 40)
	bigFont = love.graphics.newFont("Liquid.ttf", 50)
	wallTile = love.graphics.newImage("wall.png")
	floorTile = love.graphics.newImage("floor.png")
	
	-- varibles
	angle = 0
	gameState = "start"
	titleVisible = 0
end

function love.update(dt)
	angle = angle + (2 * dt)
	if gameState == "start" then
		titleVisible = math.min(255, titleVisible + (100 * dt))
	end
	if titleVisible >= 255 and gameState == "start" then
		gameState = "menu"
	end
	if gameState == "play" then
		game:update(dt)
	end
	
end

function love.mousepressed(mouseX, mouseY, button, isTouch)
	if button == 1 and gameState == "menu" then
		if mouseX > WINDOW_WIDTH/2 - 100 and mouseX < WINDOW_WIDTH/2 + 100 and mouseY >  WINDOW_HEIGHT/2 and mouseY < WINDOW_HEIGHT/2 + 50 then
			print("Play clicked")
			game = Game(1)
			gameState = "play"
		end
		if mouseX > WINDOW_WIDTH/2 - 100 and mouseX < WINDOW_WIDTH/2 + 100 and mouseY >  WINDOW_HEIGHT/2 + 100 and mouseY < WINDOW_HEIGHT/2 + 150 then
			print("Options clicked")
			gameState = "options"
		end
		if mouseX > WINDOW_WIDTH/2 - 100 and mouseX < WINDOW_WIDTH/2 + 100 and mouseY >  WINDOW_HEIGHT/2 + 200 and mouseY < WINDOW_HEIGHT/2 + 250 then
			print("Exit clicked")
			love.event.quit()
		end
	end
end

function love.draw()
	love.graphics.setColor(255,255,255,255)
	love.graphics.draw(background, 0, 0)
	love.graphics.setColor(255,255,255,100)
	love.graphics.setBlendMode("add")
	love.graphics.draw(ring, WINDOW_WIDTH/2, WINDOW_HEIGHT/2, angle, 1, 1, 100, 100)
	love.graphics.setBlendMode("alpha")
	if gameState == "start" or gameState == "menu" then
		love.graphics.setFont(bigFont)
		love.graphics.setColor(255,0,255,titleVisible)
		love.graphics.printf("Snake Expansion", 0, WINDOW_HEIGHT/4, WINDOW_WIDTH, "center")
		love.graphics.setFont(normalFont)
		love.graphics.printf("Play", 0, WINDOW_HEIGHT/2, WINDOW_WIDTH, "center")
		love.graphics.printf("Options", 0, WINDOW_HEIGHT/2 + 100, WINDOW_WIDTH, "center")
		love.graphics.printf("Exit", 0, WINDOW_HEIGHT/2 + 200, WINDOW_WIDTH, "center")
	end
	love.graphics.setColor(255, 255, 255, 255)
	if gameState == "play" then
		game:draw()
	end
end